@@ -16,6 +16,9 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
+from typing import Optional, Tuple, Union
+
+from matplotlib.figure import Figure
 import numpy as np
 from scipy.interpolate import griddata
 
@@ -25,7 +28,8 @@ from orix.plot.direction_color_keys._util import (
     rgb_from_polar_coordinates,
 )
 from orix.projections import StereographicProjection
-from orix.sampling import sample_S2_cube_mesh
+from orix.quaternion import Symmetry
+from orix.sampling import sample_S2
 from orix.vector import Vector3d
 
 
@@ -37,21 +41,21 @@ class DirectionColorKeyTSL(DirectionColorKey):
     This is based on the TSL color key implemented in MTEX.
     """
 
-    def __init__(self, symmetry):
+    def __init__(self, symmetry: Symmetry) -> None:
         """Create an inverse pole figure (IPF) color key to color
         crystal directions according to a Laue symmetry's fundamental
         sector (IPF).
 
         Parameters
         ----------
-        symmetry : orix.quaternion.Symmetry
+        symmetry
             (Laue) symmetry of the crystal. If a non-Laue symmetry
             is given, the Laue symmetry of that symmetry will be used.
         """
         laue_symmetry = symmetry.laue
         super().__init__(laue_symmetry)
 
-    def direction2color(self, direction):
+    def direction2color(self, direction: Vector3d) -> np.ndarray:
         """Return an RGB color per orientation given a Laue symmetry
         and a sample direction.
 
@@ -59,13 +63,13 @@ class DirectionColorKeyTSL(DirectionColorKey):
 
         Parameters
         ----------
-        direction : orix.vector.Vector3d
+        direction
             Directions to color.
 
         Returns
         -------
-        rgb : numpy.ndarray
-            Color array of shape `direction.shape` + (3,).
+        rgb
+            Color array of shape ``direction.shape + (3,)``.
         """
         laue_group = self.symmetry
         h = direction.in_fundamental_sector(laue_group)
@@ -73,25 +77,37 @@ class DirectionColorKeyTSL(DirectionColorKey):
         polar = 0.5 + polar / 2
         return rgb_from_polar_coordinates(azimuth, polar)
 
-    def plot(self, return_figure=False):
-        """Plot the inverse pole figure color key.
+    def _create_rgba_grid(
+        self, alpha: float = 1.0, return_extent: bool = False
+    ) -> Union[
+        np.ndarray,
+        Tuple[np.ndarray, Tuple[Tuple[float, float], Tuple[float, float]]],
+    ]:
+        """Create the 2d colormap used to represent crystal directions.
 
         Parameters
         ----------
-        return_figure : bool, optional
-            Whether to return the figure. Default is False.
+        alpha
+            Transparency value for plot.
+        return_extent
+            If ``True`` a tuple of tuples ``(min, max)`` representing
+            the extent of the fundamental sector in the stereographic
+            projection for both ``x`` and ``y`` is also returned.
+            Default is ``False``.
 
         Returns
         -------
-        figure : matplotlib.figure.Figure
-            Color key figure, returned if `return_figure` is True.
+        rgba_grid
+            Colormap values with RGBA channels.
+        extent
+            Tuple of tuples ``(min, max)`` representing the extent of
+            the fundamental sector in the stereographic projection for
+            both ``x`` and ``y``. Returned if ``return_extent=True``.
         """
-        from orix.plot.inverse_pole_figure_plot import _setup_inverse_pole_figure_plot
-
         laue_group = self.symmetry
         sector = laue_group.fundamental_sector
 
-        v = sample_S2_cube_mesh(2)
+        v = sample_S2(2)
         v2 = Vector3d(np.row_stack((v[v <= sector].data, sector.edges.data)))
 
         rgb = self.direction2color(v2)
@@ -114,19 +130,39 @@ class DirectionColorKeyTSL(DirectionColorKey):
         r2 = griddata(values=r, **griddata_kwargs)
         g2 = griddata(values=g, **griddata_kwargs)
         b2 = griddata(values=b, **griddata_kwargs)
-        rgb_grid = np.clip(np.dstack((r2, g2, b2)), 0, 1)
-        rgb_grid[np.isnan(r2)] = 1
-        rgb_grid = np.flipud(rgb_grid)
+        a2 = np.full_like(r2, alpha)
+        # create RGBA image and clip to ensure [0..1] range
+        rgba_grid = np.dstack((r2, g2, b2, a2)).clip(0, 1)
+        # some values are NaN as they are not within fundamental zone
+        NaN_values = np.isnan(r2)
+        rgba_grid[NaN_values] = 1  # set to valid values
+        # make invalid points transparent
+        rgba_grid[NaN_values, -1] = 0
+        rgba_grid = rgba_grid[::-1]
 
-        fig, axes = _setup_inverse_pole_figure_plot(laue_group)
+        if return_extent:
+            return rgba_grid, ((x_min, x_max), (y_min, y_max))
+        else:
+            return rgba_grid
+
+    def plot(self, return_figure: bool = False) -> Optional[Figure]:
+        """Plot the inverse pole figure color key.
+
+        Parameters
+        ----------
+        return_figure
+            Whether to return the figure. Default is ``False``.
+
+        Returns
+        -------
+        figure
+            Color key figure, returned if ``return_figure=True``.
+        """
+        from orix.plot.inverse_pole_figure_plot import _setup_inverse_pole_figure_plot
+
+        fig, axes = _setup_inverse_pole_figure_plot(self.symmetry)
         ax = axes[0]
-        for loc in ["left", "center", "right"]:
-            title = ax.get_title(loc)
-            if title != "":
-                ax.set_title(laue_group.name, loc=loc, fontweight="bold")
-        ax.stereographic_grid(False)
-        ax._edge_patch.set_linewidth(1.5)
-        ax.imshow(rgb_grid, extent=(x_min, x_max, y_min, y_max), zorder=0)
+        ax.plot_ipf_color_key()
 
         if return_figure:
             return fig
