@@ -33,6 +33,8 @@ from orix.io import _overwrite_or_not, _plugin_from_manufacturer, load, loadctf,
 from orix.io.plugins import bruker_h5ebsd, emsoft_h5ebsd, orix_hdf5
 from orix.quaternion.rotation import Rotation
 
+# TODO: Remove all pytest.mark.filterwarnings after (any) one release after 0.10.1
+
 
 @contextmanager
 def replace_stdin(target):
@@ -67,6 +69,7 @@ def assert_dictionaries_are_equal(input_dict, output_dict):
                 assert input_value == output_value
 
 
+@pytest.mark.filterwarnings("ignore:Argument `z` is deprecated and will be removed in")
 class TestGeneralIO:
     def test_load_no_filename_match(self):
         fname = "what_is_hip.ang"
