@@ -19,12 +19,7 @@
 import numpy as np
 import pytest
 
-from orix.base import DimensionError, Object3d, check
-
-
-@pytest.mark.xfail(strict=True, reason=ValueError)
-def test_check_failing():
-    check(np.asarray([1, 1, 1, 1]), Object3d)
+from orix.base import DimensionError, Object3d
 
 
 @pytest.fixture(
